@@ -38,6 +38,7 @@ import subprocess
 import logging
 import threading
 import sys
+import time
 
 import gi
 gi.require_version("Gdk", "3.0")
@@ -144,18 +145,6 @@ def error(parent_window, summary, msg):
     return False
 
 
-def get_dependencies(apt_cache, package_name, pattern=None):
-    """ Get the package dependencies, which can be filtered out by a pattern """
-    dependencies = []
-    for or_group in apt_cache[package_name].candidate.dependencies:
-        for dep in or_group:
-            if dep.rawtype in ["Depends", "PreDepends"]:
-                dependencies.append(dep.name)
-    if pattern:
-        dependencies = [ x for x in dependencies if x.find(pattern) != -1 ]
-    return dependencies
-
-
 class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
 
     def __init__(self, datadir=None, options=None, file=None, parent=None):
@@ -847,6 +836,13 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
 
     def on_isv_source_toggled(self, cell_toggle, path, store):
         """Enable or disable the selected channel"""
+
+        #FIXME Gtk is doing something that takes a lock while processing
+        # the events, the polkit auth dialog can't be displayed in return,
+        # we don't have a proper fix and it might require GTK changes,
+        # meanwhile we want a working interface so workaround with a sleep
+        # https://launchpad.net/bugs/1727908
+        time.sleep(0.3)
         #FIXME cdroms need to disable the comps in the childs and sources
         iter = store.get_iter((int(path),))
         source_entry = store.get_value(iter, STORE_SOURCE)
@@ -1193,7 +1189,7 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
                 # We need to collect its dependencies, so that
                 # we can uninstall the driver properly.
                 if 'nvidia' in pkg.shortname:
-                    for dep in get_dependencies(self.apt_cache, pkg.shortname, 'nvidia'):
+                    for dep in self.get_dependencies(self.apt_cache, pkg.shortname, 'nvidia'):
                         dep_pkg = self.apt_cache[dep]
                         if dep_pkg.is_installed:
                             removals.append(self.get_package_id(dep_pkg.installed))
