@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 import apt_pkg
+import aptsources
 
 import logging
 from mock import patch
@@ -22,6 +23,12 @@ class SoftwarePropertiesTestCase(unittest.TestCase):
         for k in apt_pkg.config.keys():
             apt_pkg.config.clear(k)
         apt_pkg.init()
+        cls.get_distro = aptsources.distro.get_distro
+        aptsources.distro.get_distro = lambda *a, **b: aptsources.distro.UbuntuDistribution(id="Ubuntu", codename="bionic", description="18.04", release="bionic")
+
+    @classmethod
+    def tearDownClass(cls):
+        aptsources.distro.get_distro = cls.get_distro
 
     def setUp(self):
         self.temp_dir = tempfile.mkdtemp()
